@@ -39,6 +39,7 @@ use hex::FromHex;
 use pass::Result;
 use ripasso::{
     crypto::CryptoImpl,
+    git::{pull, push},
     pass,
     pass::{
         all_recipients_from_stores, OwnerTrustLevel, PasswordStore, Recipient, SignatureStatus,
@@ -60,8 +61,9 @@ type StoreListType = Arc<Mutex<Vec<Arc<Mutex<PasswordStore>>>>>;
 
 lazy_static! {
     static ref CATALOG: gettext::Catalog = get_translation_catalog();
-    static ref DEFAULT_TERMINAL_SIZE: (usize, usize) = match term_size::dimensions() {
-        Some((w, h)) => (w + 8, h),
+    static ref DEFAULT_TERMINAL_SIZE: (usize, usize) = match terminal_size::terminal_size() {
+        Some((terminal_size::Width(w), terminal_size::Height(h))) =>
+            (usize::from(w + 8), usize::from(h)),
         _ => (0, 0),
     };
 }
@@ -577,7 +579,7 @@ fn create_save(s: &mut Cursive, store: PasswordStoreType) {
 
     let note = s.call_on_name("note_input", |e: &mut TextArea| e.get_content().to_string());
     if let Some(note) = note {
-        password = Rc::from(format!("{}\n{}", password, note));
+        password = Rc::from(format!("{password}\n{note}"));
     }
 
     if password.contains("otpauth://") {
@@ -938,7 +940,7 @@ fn help() {
 }
 
 fn git_push(ui: &mut Cursive, store: PasswordStoreType) {
-    let push_result = pass::push(&store.lock().unwrap().lock().unwrap());
+    let push_result = push(&store.lock().unwrap().lock().unwrap());
     match push_result {
         Err(err) => helpers::errorbox(ui, &err),
         Ok(_) => {
@@ -950,8 +952,7 @@ fn git_push(ui: &mut Cursive, store: PasswordStoreType) {
 }
 
 fn git_pull(ui: &mut Cursive, store: PasswordStoreType) {
-    let _ = pass::pull(&store.lock().unwrap().lock().unwrap())
-        .map_err(|err| helpers::errorbox(ui, &err));
+    let _ = pull(&store.lock().unwrap().lock().unwrap()).map_err(|err| helpers::errorbox(ui, &err));
     let _ = store
         .lock()
         .unwrap()
@@ -1073,7 +1074,7 @@ fn do_delete_last_word(ui: &mut Cursive, store: PasswordStoreType) {
 fn get_translation_catalog() -> gettext::Catalog {
     let locale = locale_config::Locale::current();
 
-    let mut translation_locations = vec!["/usr/share/ripasso"];
+    let mut translation_locations = vec![];
     if let Some(path) = option_env!("TRANSLATION_INPUT_PATH") {
         translation_locations.insert(0, path);
     }
@@ -1084,7 +1085,7 @@ fn get_translation_catalog() -> gettext::Catalog {
     for preferred in locale.tags_for("messages") {
         for loc in &translation_locations {
             let langid_res: std::result::Result<LanguageIdentifier, _> =
-                format!("{}", preferred).parse();
+                format!("{preferred}").parse();
 
             if let Ok(langid) = langid_res {
                 let file = std::fs::File::open(format!("{}/{}.mo", loc, langid.language));
@@ -1097,6 +1098,22 @@ fn get_translation_catalog() -> gettext::Catalog {
         }
     }
 
+    for preferred in locale.tags_for("messages") {
+        let langid_res: std::result::Result<LanguageIdentifier, _> = format!("{preferred}").parse();
+
+        if let Ok(langid) = langid_res {
+            let file = std::fs::File::open(format!(
+                "/usr/share/locale/{}/LC_MESSAGES/ripasso-cursive.mo",
+                langid.language
+            ));
+            if let Ok(file) = file {
+                if let Ok(catalog) = gettext::Catalog::parse(file) {
+                    return catalog;
+                }
+            }
+        }
+    }
+
     gettext::Catalog::empty()
 }
 
@@ -1169,6 +1186,19 @@ fn get_stores(config: &config::Config, home: &Option<PathBuf>) -> Result<Vec<Pas
                 )?);
             }
         }
+    } else if final_stores.is_empty() && home.is_some() {
+        let default_path = home.clone().unwrap().join(".password_store");
+        if default_path.exists() {
+            final_stores.push(PasswordStore::new(
+                "default",
+                &Some(default_path),
+                &None,
+                home,
+                &None,
+                &CryptoImpl::GpgMe,
+                &None,
+            )?);
+        }
     }
 
     Ok(final_stores)
@@ -1176,7 +1206,7 @@ fn get_stores(config: &config::Config, home: &Option<PathBuf>) -> Result<Vec<Pas
 
 /// Validates the config for password stores.
 /// Returns a list of paths that the new store wizard should be run for
-fn validate_stores_config(settings: &config::Config) -> Vec<PathBuf> {
+fn validate_stores_config(settings: &config::Config, home: &Option<PathBuf>) -> Vec<PathBuf> {
     let mut incomplete_stores: Vec<PathBuf> = vec![];
 
     let stores_res = settings.get("stores");
@@ -1202,6 +1232,8 @@ fn validate_stores_config(settings: &config::Config) -> Vec<PathBuf> {
                 }
             }
         }
+    } else if incomplete_stores.is_empty() && home.is_some() {
+        incomplete_stores.push(home.clone().unwrap().join(".password_store"));
     }
 
     incomplete_stores
@@ -1227,8 +1259,7 @@ fn save_edit_config(
             .iter()
             .enumerate()
         {
-            if is_checkbox_checked(ui, &format!("edit_recipient_{}", i)) && r.fingerprint.is_some()
-            {
+            if is_checkbox_checked(ui, &format!("edit_recipient_{i}")) && r.fingerprint.is_some() {
                 recipients.push(r.clone());
             }
         }
@@ -1306,7 +1337,7 @@ fn save_new_config(
 
     let mut recipients = vec![];
     for (i, r) in all_recipients.iter().enumerate() {
-        if is_checkbox_checked(ui, &format!("new_recipient_{}", i)) {
+        if is_checkbox_checked(ui, &format!("new_recipient_{i}")) {
             recipients.push(r.clone());
         }
     }
@@ -1454,7 +1485,7 @@ fn edit_store_in_config(
         if store_recipients.contains(recipient) {
             c.set_checked(true);
         }
-        row.add_child(c.with_name(format!("new_recipient_{}", i)));
+        row.add_child(c.with_name(format!("new_recipient_{i}")));
         fields.add_child(row);
     }
 
@@ -1585,7 +1616,7 @@ fn add_store_to_config(
     for (i, recipient) in all_recipients.iter().enumerate() {
         let mut row = LinearLayout::horizontal();
         row.add_child(TextView::new(&recipient.name).fixed_size((30_usize, 1_usize)));
-        row.add_child(Checkbox::new().with_name(format!("new_recipient_{}", i)));
+        row.add_child(Checkbox::new().with_name(format!("new_recipient_{i}")));
         fields.add_child(row);
     }
     fields.add_child(pgp_fields);
@@ -1651,12 +1682,11 @@ fn show_manage_config_dialog(
         .h_align(cursive::align::HAlign::Left)
         .with_name("stores");
 
-    #[allow(clippy::significant_drop_in_scrutinee)]
     for store in stores.lock().unwrap().iter() {
-        stores_view.get_mut().add_item(
-            store.lock().unwrap().get_name(),
-            store.lock().unwrap().get_name().clone(),
-        );
+        let store = store.lock().unwrap();
+        stores_view
+            .get_mut()
+            .add_item(store.get_name(), store.get_name().clone());
     }
 
     let d = Dialog::around(stores_view)
@@ -1758,7 +1788,7 @@ fn main() {
         let password_store_signing_key = std::env::var("PASSWORD_STORE_SIGNING_KEY").ok();
         let xdg_config_home = match std::env::var("XDG_CONFIG_HOME") {
             Err(_) => None,
-            Ok(home_path) => Some(PathBuf::from(home_path)),
+            Ok(config_home_path) => Some(PathBuf::from(config_home_path)),
         };
 
         pass::read_config(
@@ -1769,20 +1799,21 @@ fn main() {
         )
     };
     if let Err(err) = config_res {
-        eprintln!("Error {}", err);
+        eprintln!("Error {err}");
         process::exit(1);
     }
     let (config, config_file_location) = config_res.unwrap();
 
-    for path in validate_stores_config(&config) {
+    for path in validate_stores_config(&config, &home) {
         wizard::show_init_menu(&Some(path), &home);
     }
 
     let stores = get_stores(&config, &home);
     if let Err(err) = stores {
-        eprintln!("Error {}", err);
+        eprintln!("Error {err}");
         process::exit(1);
     }
+
     let stores: StoreListType = Arc::new(Mutex::new(
         stores
             .unwrap()
@@ -1791,6 +1822,19 @@ fn main() {
             .collect(),
     ));
 
+    if !config_file_location.exists() && stores.lock().unwrap().len() == 1 {
+        let mut config_file_dir = config_file_location.clone();
+        config_file_dir.pop();
+        if let Err(err) = std::fs::create_dir_all(config_file_dir) {
+            eprintln!("Error {err}");
+            process::exit(1);
+        }
+        if let Err(err) = pass::save_config(stores.clone(), &config_file_location) {
+            eprintln!("Error {err}");
+            process::exit(1);
+        }
+    }
+
     let store: PasswordStoreType = Arc::new(Mutex::new(stores.lock().unwrap()[0].clone()));
     #[allow(clippy::significant_drop_in_scrutinee)]
     for ss in stores.lock().unwrap().iter() {
@@ -1801,7 +1845,7 @@ fn main() {
     }
     let res = store.lock().unwrap().lock().unwrap().reload_password_list();
     if let Err(err) = res {
-        eprintln!("Error {}", err);
+        eprintln!("Error {err}");
         process::exit(1);
     }
 
@@ -1897,7 +1941,7 @@ fn main() {
     if let Err(err) = ui.load_toml(&get_style(
         &store.lock().unwrap().lock().unwrap().get_style_file(),
     )) {
-        eprintln!("Error {:?}", err);
+        eprintln!("Error {err:?}");
         process::exit(1);
     }
     let search_box = EditView::new()
@@ -2010,7 +2054,7 @@ fn main() {
 
                 let res = to_store.lock().unwrap().reload_password_list();
                 if let Err(err) = res {
-                    eprintln!("Error {}", err);
+                    eprintln!("Error {err}");
                     process::exit(1);
                 }
             }
@@ -2018,7 +2062,7 @@ fn main() {
             if let Err(err) = ui.load_toml(&get_style(
                 &store.lock().unwrap().lock().unwrap().get_style_file(),
             )) {
-                eprintln!("Error {:?}", err);
+                eprintln!("Error {err:?}");
                 process::exit(1);
             }
 
